再利用可能なCUDA_CHECKマクロ
安全のためすべての呼び出しをラップします。
「再利用可能なCUDA_CHECKマクロ」はCoddyKit上の無料CUDA Academyレッスンです。 これはレッスン3/4です。 下記で完全なレッスンを無料で読むことができます。その後、ブラウザ内の組み込みコードエディタと24時間対応のAIチューターでハンズオン演習できます。 これはCUDA Academy学習パスの一部であり、ウェブとCoddyKitアプリ全体で進捗が同期されます。 CUDA Academyコースには全4レッスンが含まれています。
このレッスンの一部はまだ翻訳されておらず、英語で表示されています。
Checking Every Call Is Tedious
Writing an if-statement after every CUDA call clutters your code fast. A reusable CUDA_CHECK macro fixes that with one clean line. 🧹
The Goal of the Macro
You want to wrap any call, grab its return code, and bail out loudly if it failed. One macro can do this everywhere.
CUDA_CHECK(cudaMalloc(&d, n));Capturing the Result
Inside, the macro stores the call result in a local cudaError_t so it can be inspected once without calling twice.
cudaError_t e = (call);Comparing to Success
It then tests the code against cudaSuccess. If they match, nothing happens and your program flows on as normal.
if (e != cudaSuccess) { /* report */ }Printing Where It Failed
On failure it prints a readable message using __FILE__ and __LINE__, so you jump straight to the offending line.
printf("CUDA error %s at %s:%d\n", msg, __FILE__, __LINE__);The do-while(0) Trick
The body is wrapped in a do-while(0). This makes the macro a single statement that works safely even inside an unbraced if.
#define CUDA_CHECK(c) do { /* ... */ } while(0)A Full Macro Sketch
Put it together and you get a compact, reusable safety net you can paste into any CUDA project header.
#define CUDA_CHECK(c) do { cudaError_t e=(c); if(e) exit(1); } while(0)Wrapping API Calls
Use it on any call that returns a code: cudaMalloc, cudaMemcpy, cudaFree. One wrapper guards them all uniformly.
CUDA_CHECK(cudaMemcpy(d, h, n, cudaMemcpyHostToDevice));Also Guard the Launch
Kernels return nothing, so wrap cudaGetLastError and a sync after the launch instead of wrapping the launch line itself.
kernel<<<g, b>>>();
CUDA_CHECK(cudaGetLastError());Keep It in a Header
Drop the macro in a shared header so every file uses the same check. Consistency here saves hours of confusing debugging.
Fail Fast, Fail Clearly
The big win is failing fast: the instant a call breaks, you get a precise file, line, and message instead of silent garbage.
Quick Check
Test your grasp of the CUDA_CHECK macro.
Recap: One Macro to Guard Them All
A CUDA_CHECK macro captures the code, compares to success, and prints file and line on failure. Define it once, use it everywhere. 🎉
よくある質問
「再利用可能なCUDA_CHECKマクロ」レッスンは無料ですか?
はい。「再利用可能なCUDA_CHECKマクロ」の完全なテキストはこのウェブで無料で読めます。インタラクティブに演習し(組み込みコードエディタと24時間対応のAIチューター)、CUDA Academyコースの残りをアンロックするには、CoddyKit PROにアップグレードしてください。 CUDA Academyコースには全4レッスンが含まれています。
「再利用可能なCUDA_CHECKマクロ」で何を学びますか?
安全のためすべての呼び出しをラップします。 ブラウザで直接実行するハンズオンコードでCUDA Academyを演習し、24時間対応のAIチューターがレッスンを進める中での質問に答えます。
CUDA Academyを始めるのに経験は必要ですか?
事前経験は必要ありません。CoddyKitのCUDA Academyは初級者から上級者向けに構成されているため、ここから始めるか最初から始めて、自分のペースで進むことができます。 これはレッスン3/4です。
「再利用可能なCUDA_CHECKマクロ」レッスンにはどのくらい時間がかかりますか?
ほとんどのCoddyKitレッスンは約5~10分かかります。各レッスンはコンパクトでインタラクティブなので、着実に進歩し、ウェブとアプリ全体で正確に前回の場所から再開できます。
このCUDA Academyレッスンでコードを書いて実行できますか?
はい。すべてのCUDA Academyレッスンに組み込みコードエディタが含まれているため、ブラウザでリアルコードを書いて実行し、即座のAIフィードバックを取得できます。ローカル設定は不要です。
このコースのすべてのレッスン
- 戻り値と非同期エラー
- 起動後にcudaGetLastErrorを使う
- 再利用可能なCUDA_CHECKマクロ
- cudaGetErrorStringを読み解く